@@ -1,4 +1,5 @@
-/* vim: set sw=4 sts=4: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* vim: set sw=4 sts=4 ts=4 expandtab: */
 /*
    rsvg-cairo-render.h: The cairo backend plugin
 
@@ -37,6 +38,8 @@ struct _RsvgCairoRender {
     cairo_t *cr;
     double width;
     double height;
+
+    cairo_t *initial_cr;
     double offset_x;
     double offset_y;
 
@@ -48,7 +51,8 @@ struct _RsvgCairoRender {
 };
 
 RsvgCairoRender *rsvg_cairo_render_new		(cairo_t * cr, double width, double height);
-void		 rsvg_cairo_render_rsvg_handle	(cairo_t * cr, RsvgHandle * handle);
+void		rsvg_cairo_render_rsvg_handle	(cairo_t * cr, RsvgHandle * handle);
+RsvgDrawingCtx *rsvg_cairo_new_drawing_ctx	(cairo_t * cr, RsvgHandle * handle);
 
 G_END_DECLS
 
